# Introdução

Lib para tratamento de erros

## Como instalar

```
$ python setup.py install
```

No seu projeto, ao iniciar o app:

- Importar

```
from exception_handler.factory_logging import init_log
```

- Chamar

```
init_log()
```

## Como utilizar

- Pode utilizar algum metodo diretamente:

```
from exception_handler.factory_logging import report_log_error
report_log_error()
```


